==> pystan-2.4.0.1.tar.gz: pystan-2.4.0.1/pystan/stan/src/stan/math/functions.hpp <==
#ifndef __STAN__MATH__FUNCTIONS_HPP__
#define __STAN__MATH__FUNCTIONS_HPP__

#include <stan/math/functions/Phi.hpp>
#include <stan/math/functions/Phi_approx.hpp>
#include <stan/math/functions/abs.hpp>
#include <stan/math/functions/as_bool.hpp>
#include <stan/math/functions/bessel_first_kind.hpp>
#include <stan/math/functions/bessel_second_kind.hpp>
#include <stan/math/functions/binary_log_loss.hpp>
#include <stan/math/functions/binomial_coefficient_log.hpp>
#include <stan/math/functions/digamma.hpp>
#include <stan/math/functions/dist.hpp>
#include <stan/math/functions/dot.hpp>
#include <stan/math/functions/dot_self.hpp>
#include <stan/math/functions/exp2.hpp>
#include <stan/math/functions/falling_factorial.hpp>
#include <stan/math/functions/fdim.hpp>
#include <stan/math/functions/fma.hpp>
#include <stan/math/functions/gamma_p.hpp>
#include <stan/math/functions/gamma_q.hpp>
#include <stan/math/functions/ibeta.hpp>
#include <stan/math/functions/if_else.hpp>
#include <stan/math/functions/int_step.hpp>
#include <stan/math/functions/inv.hpp>
#include <stan/math/functions/inv_cloglog.hpp>
#include <stan/math/functions/inv_logit.hpp>
#include <stan/math/functions/inv_sqrt.hpp>
#include <stan/math/functions/inv_square.hpp>
#include <stan/math/functions/inverse_softmax.hpp>
#include <stan/math/functions/is_uninitialized.hpp>
#include <stan/math/functions/lbeta.hpp>
#include <stan/math/functions/lgamma.hpp>
#include <stan/math/functions/lmgamma.hpp>
#include <stan/math/functions/log1m.hpp>
#include <stan/math/functions/log1m_exp.hpp>
#include <stan/math/functions/log1m_inv_logit.hpp>
#include <stan/math/functions/log1p.hpp>
#include <stan/math/functions/log1p_exp.hpp>
#include <stan/math/functions/log2.hpp>
#include <stan/math/functions/log_diff_exp.hpp>
#include <stan/math/functions/log_falling_factorial.hpp>
#include <stan/math/functions/log_inv_logit.hpp>
#include <stan/math/functions/log_rising_factorial.hpp>
#include <stan/math/functions/log_sum_exp.hpp>
#include <stan/math/functions/logical_and.hpp>
#include <stan/math/functions/logical_eq.hpp>
#include <stan/math/functions/logical_gt.hpp>
#include <stan/math/functions/logical_gte.hpp>
#include <stan/math/functions/logical_lt.hpp>
#include <stan/math/functions/logical_lte.hpp>
#include <stan/math/functions/logical_negation.hpp>
#include <stan/math/functions/logical_neq.hpp>
#include <stan/math/functions/logical_or.hpp>
#include <stan/math/functions/logit.hpp>
#include <stan/math/functions/max.hpp>
#include <stan/math/functions/min.hpp>
#include <stan/math/functions/modified_bessel_first_kind.hpp>
#include <stan/math/functions/modified_bessel_second_kind.hpp>
#include <stan/math/functions/multiply_log.hpp>
#include <stan/math/functions/owens_t.hpp>
#include <stan/math/functions/rising_factorial.hpp>
#include <stan/math/functions/scaled_add.hpp>
#include <stan/math/functions/square.hpp>
#include <stan/math/functions/step.hpp>
#include <stan/math/functions/sub.hpp>
#include <stan/math/functions/sum.hpp>
#include <stan/math/functions/trigamma.hpp>
#include <stan/math/functions/value_of.hpp>

#endif

==> pystan-2.5.0.1.tar.gz: pystan-2.5.0.1/pystan/stan/src/stan/math/functions.hpp <==
#ifndef STAN__MATH__FUNCTIONS_HPP
#define STAN__MATH__FUNCTIONS_HPP

#include <stan/math/functions/Phi.hpp>
#include <stan/math/functions/Phi_approx.hpp>
#include <stan/math/functions/abs.hpp>
#include <stan/math/functions/as_bool.hpp>
#include <stan/math/functions/bessel_first_kind.hpp>
#include <stan/math/functions/bessel_second_kind.hpp>
#include <stan/math/functions/binary_log_loss.hpp>
#include <stan/math/functions/binomial_coefficient_log.hpp>
#include <stan/math/functions/digamma.hpp>
#include <stan/math/functions/dist.hpp>
#include <stan/math/functions/divide.hpp>
#include <stan/math/functions/dot.hpp>
#include <stan/math/functions/dot_self.hpp>
#include <stan/math/functions/exp2.hpp>
#include <stan/math/functions/falling_factorial.hpp>
#include <stan/math/functions/fdim.hpp>
#include <stan/math/functions/gamma_p.hpp>
#include <stan/math/functions/gamma_q.hpp>
#include <stan/math/functions/ibeta.hpp>
#include <stan/math/functions/if_else.hpp>
#include <stan/math/functions/int_step.hpp>
#include <stan/math/functions/inv.hpp>
#include <stan/math/functions/inv_cloglog.hpp>
#include <stan/math/functions/inv_logit.hpp>
#include <stan/math/functions/inv_sqrt.hpp>
#include <stan/math/functions/inv_square.hpp>
#include <stan/math/functions/inverse_softmax.hpp>
#include <stan/math/functions/is_inf.hpp>
#include <stan/math/functions/is_nan.hpp>
#include <stan/math/functions/is_uninitialized.hpp>
#include <stan/math/functions/lbeta.hpp>
#include <stan/math/functions/lgamma.hpp>
#include <stan/math/functions/lmgamma.hpp>
#include <stan/math/functions/log1m.hpp>
#include <stan/math/functions/log1m_exp.hpp>
#include <stan/math/functions/log1m_inv_logit.hpp>
#include <stan/math/functions/log1p.hpp>
#include <stan/math/functions/log1p_exp.hpp>
#include <stan/math/functions/log2.hpp>
#include <stan/math/functions/log_diff_exp.hpp>
#include <stan/math/functions/log_falling_factorial.hpp>
#include <stan/math/functions/log_inv_logit.hpp>
#include <stan/math/functions/log_rising_factorial.hpp>
#include <stan/math/functions/log_sum_exp.hpp>
#include <stan/math/functions/logical_and.hpp>
#include <stan/math/functions/logical_eq.hpp>
#include <stan/math/functions/logical_gt.hpp>
#include <stan/math/functions/logical_gte.hpp>
#include <stan/math/functions/logical_lt.hpp>
#include <stan/math/functions/logical_lte.hpp>
#include <stan/math/functions/logical_negation.hpp>
#include <stan/math/functions/logical_neq.hpp>
#include <stan/math/functions/logical_or.hpp>
#include <stan/math/functions/logit.hpp>
#include <stan/math/functions/max.hpp>
#include <stan/math/functions/min.hpp>
#include <stan/math/functions/modified_bessel_first_kind.hpp>
#include <stan/math/functions/modified_bessel_second_kind.hpp>
#include <stan/math/functions/modulus.hpp>
#include <stan/math/functions/multiply_log.hpp>
#include <stan/math/functions/owens_t.hpp>
#include <stan/math/functions/primitive_value.hpp>
#include <stan/math/functions/rising_factorial.hpp>
#include <stan/math/functions/scaled_add.hpp>
#include <stan/math/functions/square.hpp>
#include <stan/math/functions/step.hpp>
#include <stan/math/functions/sub.hpp>
#include <stan/math/functions/sum.hpp>
#include <stan/math/functions/trigamma.hpp>
#include <stan/math/functions/value_of.hpp>

#endif
